==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/sv.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Uppgifter",
    "Personal" : "Privat",
    "{actor} created calendar {calendar}" : "{actor} skapade kalender {calendar}",
    "You created calendar {calendar}" : "Du skapade kalender {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} raderade kalender {calendar}",
    "You deleted calendar {calendar}" : "Du raderade kalender {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppdaterade kalender {calendar}",
    "You updated calendar {calendar}" : "Du uppdaterade kalender {calendar}",
    "You shared calendar {calendar} as public link" : "Du delade kalender {calendar} som offentlig länk",
    "You removed public link for calendar {calendar}" : "Du tog bort offentlig länk för kalender {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delade kalender {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delade kalender {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delade kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} slutade dela kalender {calendar} med dig",
    "You unshared calendar {calendar} from {user}" : "Du slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} slutade dela kalender {calendar} med sig själv",
    "You shared calendar {calendar} with group {group}" : "Du delade kalender {calendar} med grupp {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delade kalender {calendar} med grupp {group}",
    "You unshared calendar {calendar} from group {group}" : "Du slutade dela kalender {calendar} med gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} slutade dela kalender {calendar} med gruppen {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} skapade händelse {event} i kalender {calendar}",
    "You created event {event} in calendar {calendar}" : "Du skapade händelse {event} i kalender {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} raderade händelse {event} från kalender {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du raderade händelse {event} från kalender {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppdaterade händelse {event} i kalender {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du uppdaterade händelse {event} i kalender {calendar}",
    "Busy" : "Upptagen",
    "{actor} created todo {todo} in list {calendar}" : "{actor} skapade uppgift {todo} i listan {calendar}",
    "You created todo {todo} in list {calendar}" : "Du skapade uppgift {todo} i listan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} raderade uppgift {todo} från listan {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du raderade uppgift {todo} från listan {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} uppdaterade uppgift {todo} i listan {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du uppdaterade uppgift {todo} i listan {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} löste uppgift {todo} i listan {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du löste uppgift {todo} i listan {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} återupptog uppgift {todo} i listan {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du återupptog uppgift {todo} i listan {calendar}",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> modifierades",
    "A calendar <strong>event</strong> was modified" : "En kalender-<strong>händelse</strong> modifierades",
    "A calendar <strong>todo</strong> was modified" : "En kalender <strong>uppgift</strong> modifierades",
    "Death of %s" : "Död av %s",
    "Contact birthdays" : "Födelsedagar",
    "Calendar:" : "Kalender:",
    "Date:" : "Datum:",
    "Where:" : "Var:",
    "Description:" : "Beskrivning:",
    "Untitled event" : "Namnlös händelse",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n månad","%n månader"],
    "_%n day_::_%n days_" : ["%n dag","%n dagar"],
    "_%n hour_::_%n hours_" : ["%n timme","%n timmar"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minuter"],
    "%s (in %s)" : "%s (på %s)",
    "%s (%s ago)" : "%s (%s sedan)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beskrivning: %s",
    "Where: %s" : "Var: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Inbjudan avbruten",
    "Hello %s," : "He %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Mötet »%1$s« med %2$s avbröts.",
    "Invitation updated" : "Inbjudan uppdaterad",
    "The meeting »%1$s« with %2$s was updated." : "Mötet »%1$s« med %2$s uppdaterades.",
    "%1$s invited you to »%2$s«" : "%1$s bjöd in dig till »%2$s«",
    "When:" : "När",
    "Link:" : "Länk:",
    "Accept" : "Acceptera",
    "Decline" : "Avböj",
    "More options …" : "Fler alternativ ...",
    "More options at %s" : "Fler alternativ på %s",
    "Contacts" : "Kontakter",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Din %s måste konfigureras att använda HTTPS för CalDAV och CardDAV med iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurerar ett CalDAV-konto",
    "Configures a CardDAV account" : "Konfigurerar ett CardDAV-konto",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Technical details" : "Tekniska detaljer",
    "Remote Address: %s" : "Extern adress: %s",
    "Request ID: %s" : "Begär ID: %s",
    "There was an error updating your attendance status." : "Ett fel uppstod vid uppdatering av din närvarostatus.",
    "Please contact the organizer directly." : "Vänligen kontakta arrangören direkt.",
    "Are you accepting the invitation?" : "Acceptera inbjudan?",
    "Tentative" : "Preliminärt",
    "Save" : "Spara",
    "Your attendance was updated successfully." : "Dina närvaro uppdaterades.",
    "Calendar server" : "Kalenderserver",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installera även {calendarappstoreopen}Kalender-app{linkclose}, eller {calendardocopen}anslut din dator & mobil för synkronisering ↗{linkclose}.",
    "Send invitations to attendees" : "Skicka inbjudan till deltagare",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Verifiera och säkerställ inställningar för {emailopen}e-postserver{linkclose}.",
    "Automatically generate a birthday calendar" : "Generera en födelsedagskalender automatiskt",
    "Birthday calendars will be generated by a background job." : "Födelsedagskalender kommer skapas som ett bakgrundsjobb.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Därför kommer de inte vara tillgängliga direkt efter aktivering men kommer dyka upp efter en tid.",
    "Send notifications for events" : "Skicka aviseringar för händelser",
    "Enable notifications for events via push" : "Aktivera aviseringar för händelser via push",
    "Please make sure to properly set up the email settings above." : "Vänligen säkerställ att epost-inställningarna ovan är korrekt angivna",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Aviseringar skickas genom bakgrundsjobb, så dessa måste ske tillräckligt ofta."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/sv.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Uppgifter",
    "Personal" : "Privat",
    "{actor} created calendar {calendar}" : "{actor} skapade kalender {calendar}",
    "You created calendar {calendar}" : "Du skapade kalender {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} raderade kalender {calendar}",
    "You deleted calendar {calendar}" : "Du raderade kalender {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppdaterade kalender {calendar}",
    "You updated calendar {calendar}" : "Du uppdaterade kalender {calendar}",
    "You shared calendar {calendar} as public link" : "Du delade kalender {calendar} som offentlig länk",
    "You removed public link for calendar {calendar}" : "Du tog bort offentlig länk för kalender {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delade kalender {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delade kalender {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delade kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} slutade dela kalender {calendar} med dig",
    "You unshared calendar {calendar} from {user}" : "Du slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} slutade dela kalender {calendar} med sig själv",
    "You shared calendar {calendar} with group {group}" : "Du delade kalender {calendar} med grupp {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delade kalender {calendar} med grupp {group}",
    "You unshared calendar {calendar} from group {group}" : "Du slutade dela kalender {calendar} med gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} slutade dela kalender {calendar} med gruppen {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} skapade händelse {event} i kalender {calendar}",
    "You created event {event} in calendar {calendar}" : "Du skapade händelse {event} i kalender {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} raderade händelse {event} från kalender {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du raderade händelse {event} från kalender {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppdaterade händelse {event} i kalender {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du uppdaterade händelse {event} i kalender {calendar}",
    "Busy" : "Upptagen",
    "{actor} created todo {todo} in list {calendar}" : "{actor} skapade uppgift {todo} i listan {calendar}",
    "You created todo {todo} in list {calendar}" : "Du skapade uppgift {todo} i listan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} raderade uppgift {todo} från listan {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du raderade uppgift {todo} från listan {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} uppdaterade uppgift {todo} i listan {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du uppdaterade uppgift {todo} i listan {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} löste uppgift {todo} i listan {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du löste uppgift {todo} i listan {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} återupptog uppgift {todo} i listan {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du återupptog uppgift {todo} i listan {calendar}",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> modifierades",
    "A calendar <strong>event</strong> was modified" : "En kalender-<strong>händelse</strong> modifierades",
    "A calendar <strong>todo</strong> was modified" : "En kalender <strong>uppgift</strong> modifierades",
    "Death of %s" : "Död av %s",
    "Contact birthdays" : "Födelsedagar",
    "Calendar:" : "Kalender:",
    "Date:" : "Datum:",
    "Where:" : "Var:",
    "Description:" : "Beskrivning:",
    "Untitled event" : "Namnlös händelse",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n månad","%n månader"],
    "_%n day_::_%n days_" : ["%n dag","%n dagar"],
    "_%n hour_::_%n hours_" : ["%n timme","%n timmar"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minuter"],
    "%s (in %s)" : "%s (på %s)",
    "%s (%s ago)" : "%s (%s sedan)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beskrivning: %s",
    "Where: %s" : "Var: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Inbjudan avbruten",
    "Hello %s," : "He %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Mötet »%1$s« med %2$s avbröts.",
    "Invitation updated" : "Inbjudan uppdaterad",
    "The meeting »%1$s« with %2$s was updated." : "Mötet »%1$s« med %2$s uppdaterades.",
    "%1$s invited you to »%2$s«" : "%1$s bjöd in dig till »%2$s«",
    "When:" : "När",
    "Link:" : "Länk:",
    "Accept" : "Acceptera",
    "Decline" : "Avböj",
    "More options …" : "Fler alternativ ...",
    "More options at %s" : "Fler alternativ på %s",
    "Contacts" : "Kontakter",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Din %s måste konfigureras att använda HTTPS för CalDAV och CardDAV med iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurerar ett CalDAV-konto",
    "Configures a CardDAV account" : "Konfigurerar ett CardDAV-konto",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Technical details" : "Tekniska detaljer",
    "Remote Address: %s" : "Extern adress: %s",
    "Request ID: %s" : "Begär ID: %s",
    "There was an error updating your attendance status." : "Ett fel uppstod vid uppdatering av din närvarostatus.",
    "Please contact the organizer directly." : "Vänligen kontakta arrangören direkt.",
    "Are you accepting the invitation?" : "Acceptera inbjudan?",
    "Tentative" : "Preliminärt",
    "Save" : "Spara",
    "Your attendance was updated successfully." : "Dina närvaro uppdaterades.",
    "Calendar server" : "Kalenderserver",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installera även {calendarappstoreopen}Kalender-app{linkclose}, eller {calendardocopen}anslut din dator & mobil för synkronisering ↗{linkclose}.",
    "Send invitations to attendees" : "Skicka inbjudan till deltagare",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Verifiera och säkerställ inställningar för {emailopen}e-postserver{linkclose}.",
    "Automatically generate a birthday calendar" : "Generera en födelsedagskalender automatiskt",
    "Birthday calendars will be generated by a background job." : "Födelsedagskalender kommer skapas som ett bakgrundsjobb.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Därför kommer de inte vara tillgängliga direkt efter aktivering men kommer dyka upp efter en tid.",
    "Send notifications for events" : "Skicka aviseringar för händelser",
    "Notifications are sent via background jobs, so these must occur often enough." : "Aviseringar skickas genom bakgrundsjobb, så dessa måste ske tillräckligt ofta.",
    "Enable notifications for events via push" : "Aktivera aviseringar för händelser via push",
    "Please make sure to properly set up the email settings above." : "Vänligen säkerställ att epost-inställningarna ovan är korrekt angivna",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Aviseringar skickas genom bakgrundsjobb, så dessa måste ske tillräckligt ofta."
},
"nplurals=2; plural=(n != 1);");
